@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,12 +11,15 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Backwards compatibility: moved this module to
-`zope.traversing.publicationtraverse`.
+import warnings
+
+warnings.warn("""%s is deprecated
+
+If you want PublicationTraverser, it's now in
+zope.traversing.publicationtraverse.  Anything else that was here is
+deprecated.
+""" % __name__, DeprecationWarning, stacklevel=1)
 
-$Id: publicationtraverse.py 100362 2009-05-25 16:40:17Z shane $
-"""
-__docformat__ = 'restructuredtext'
 
 from zope.traversing.publicationtraverse import PublicationTraverse #BBB import
 from zope.traversing.publicationtraverse import PublicationTraverser #BBB import
@@ -28,4 +31,3 @@ class DuplicateNamespaces(Exception):
 #BBB: do not use
 class UnknownNamespace(Exception):
     """A parameter specified an unknown namespace"""
-
